@@ -1,10 +1,6 @@
-import warnings
-
 import htmlgenerator as hg
 from django.utils.translation import gettext_lazy as _
 
-from bread.utils.links import Link
-
 from .icon import Icon
 
 
@@ -44,24 +40,6 @@ class Button(hg.BUTTON):
             children += (icon,)
         super().__init__(*children, **attributes)
 
-    @staticmethod
-    def fromaction(action, **kwargs):
-        warnings.warn(
-            "Button.fromaction is going to be deprecated in the future. Try to use bread.utils.links.Link where possible"
-        )
-        buttonargs = {
-            "icon": action.iconname,
-            "notext": not action.label,
-        }
-        if isinstance(action, Link):
-            buttonargs["onclick"] = hg.F(
-                lambda c: f"document.location = '{hg.resolve_lazy(action.href, c)}'"
-            )
-        else:
-            buttonargs["onclick"] = action.js
-        buttonargs.update(kwargs)
-        return Button(*([action.label] if action.label else []), **buttonargs)
-
     @staticmethod
     def fromlink(link, **kwargs):
         buttonargs = {
@@ -69,7 +47,8 @@ class Button(hg.BUTTON):
             "notext": not link.label,
         }
         return Button(
-            *([link.label] if link.label else []), **{**buttonargs, **kwargs}
+            *([link.label] if link.label else []),
+            **{**buttonargs, **link.attributes, **kwargs},
         ).as_href(link.href)
 
     def as_href(self, href):
